#!%PERL% -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


# This file is a part of the VHFFS plateform
# Please respect the entire licence of VHFFS
# 
# Author : Julien Delange < dieu at gunnm dot org >

package Vhffs::Mailings;

use utf8;
use strict;
use Vhffs::Functions;
use Vhffs::Constants;
use Encode;

sub add_mailing
{
	my $vhffs = shift;	
	my $subject = shift;
	my $message = shift;
	
	return -1 unless defined $vhffs;

	my $query = 'INSERT INTO vhffs_mailings (subject,message,date,state) VALUES( ? , ? , ? , ? )';
	my $request = $vhffs->{'db'}->prepare( $query );
	$request->execute($subject, $message, time(), Vhffs::Constants::WAITING_FOR_CREATION) or return -2;

	return 1;
}


sub getall
{
	my $vhffs = shift;
	my $state = shift;
	my @params;

	my $query = 'SELECT id_mailing,subject,message,date,state FROM vhffs_mailings ';
	if( defined $state ) {
		$query .= ' WHERE state=?';
		push @params, $state;
	}

	my $request = $vhffs->{'db'}->prepare( $query );
	$request->execute( @params ) or return undef;
    
	my $rows = $request->fetchall_hashref( 'id_mailing' );
	return $rows;
}



sub del_mailing
{
	my $vhffs = shift;	
	my $id = shift;
	my $db = $vhffs->get_db_object;

	my $query = 'DELETE FROM vhffs_mailings WHERE id_mailing=?';
	my $request = $db->prepare( $query );
	$request->execute( $id ) or return -2;

	return 1;
}


sub get_mailing
{
	my $vhffs = shift;	
	my $id = shift;
	my $db = $vhffs->get_db_object;

	return undef unless defined $id;
	
	my $query = 'SELECT id_mailing,subject,message,date,state FROM vhffs_mailings WHERE id_mailing=?';
	my $request = $db->prepare( $query );
	$request->execute( $id ) or return -2;

	my $row = $request->fetchrow_hashref();
	return $row;
}

1;
