#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;

package Vhffs::Panel::Cvs;

use DBI;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Acl;
use Vhffs::Services::Cvs;
use Vhffs::Panel::Main;
use Vhffs::Constants;

sub search
{
    my ($main, $name) = @_;
    my $sql;
    my @params;
    my $cvs = [];
    
    if( defined $name ) {
        $sql = 'SELECT c.cvsroot, g.groupname, o.state FROM vhffs_cvs c INNER JOIN vhffs_object o ON o.object_id = c.object_id INNER JOIN vhffs_groups g ON g.gid = o.owner_gid WHERE cvsroot LIKE ?';
        push(@params, '%'.lc($name).'%');
    } else {
        $sql = 'SELECT c.cvsroot, g.groupname, o.state FROM vhffs_cvs c INNER JOIN vhffs_object o ON o.object_id = c.object_id INNER JOIN vhffs_groups g ON g.gid = o.owner_gid';
    }
    my $dbh = $main->get_db_object();
    my $sth = $dbh->prepare($sql) or return undef;

    return undef unless($sth->execute(@params));
    
    while(my $c = $sth->fetchrow_hashref('NAME_lc')) {
        $c->{state} = Vhffs::Functions::status_string_from_status_id($c->{state});
        push(@$cvs, $c);
    }
    return $cvs;
}


sub create_cvs
{
	my( $main, $cvsroot, $description, $user, $group ) = @_;

	return undef if( ! defined $user );
	return undef if( ! defined $group );

    my $cvs = Vhffs::Services::Cvs::create($main, $cvsroot, $description, $user, $group);

	return undef if( ! defined $cvs);

	return undef if ( Vhffs::Acl::add_acl( $user , $cvs , Vhffs::Constants::ACL_DELETE , $main ) < 0 );
	return undef if( Vhffs::Acl::add_acl( $group , $cvs , Vhffs::Constants::ACL_VIEW , $main ) < 0 );

	return $cvs;
}

=pod

=head2 getall_per_group

    $cvs = Vhffs::Panel::Cvs::getall_per_group($vhffs, $gid);

Returns an array of hashrefs (oid, displayname, active, state (localized string)) of all CVS repos owned by
a given group.

=cut


sub getall_per_group
{
    my ( $main, $gid ) = @_;

    my $dbh = $main->get_db_object;
    my $sql = 'SELECT c.object_id AS oid, c.cvsroot AS displayname, o.state FROM vhffs_cvs c INNER JOIN vhffs_object o ON c.object_id = o.object_id WHERE o.owner_gid = ? ORDER BY c.cvsroot';
    my $sth = $dbh->prepare($sql) or return -1;
    $sth->execute($gid) or return -2;
    my $cvs = [];
    while(my $c = $sth->fetchrow_hashref) {
        $c->{active} = ($c->{state} == Vhffs::Constants::ACTIVATED);
        $c->{refused} = ($c->{state} == Vhffs::Constants::VALIDATION_REFUSED);
        $c->{state} = Vhffs::Functions::status_string_from_status_id($c->{state});
        push @$cvs, $c;
    }
    return $cvs;
}

sub get_repos_per_group {
    my ($main, $gid) = @_;

    my $dbh = $main->get_db_object;
    my $sql = 'SELECT c.cvsroot, o.description FROM vhffs_cvs c INNER JOIN vhffs_object o ON o.object_id = c.object_id WHERE o.owner_gid = ? AND o.state = ?';
    return $dbh->selectall_arrayref($sql, { Slice => {} }, $gid, Vhffs::Constants::ACTIVATED);
}

1;
