#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;

package Vhffs::Panel::Mysql;

use DBI;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Services::Mysql;

=pod

=head1 NAME

Vhffs::Panel::Mysql - Lightweight objects for MySQL DBs handling in VHFFS panel.

=head1 METHODS

=cut


sub search
{
    my ($main, $name) = @_; 
    
    my $sql;
    my @params;
    my $mys = [];

    if( defined $name ) {
        $sql = 'SELECT m.dbname, g.groupname, o.state FROM vhffs_mysql m INNER JOIN vhffs_object o ON o.object_id = m.object_id INNER JOIN vhffs_groups g ON g.gid = o.owner_gid WHERE m.dbname LIKE ? OR m.dbuser LIKE ?';
        push(@params, '%'.lc($name).'%' , '%'.lc($name).'%' );
    } else {
        $sql = 'SELECT m.dbname, g.groupname, o.state FROM vhffs_mysql m INNER JOIN vhffs_object o ON o.object_id = m.object_id INNER JOIN vhffs_groups g ON g.gid = o.owner_gid';
    }

    my $dbh = $main->get_db_object();
    my $sth = $dbh->prepare( $sql) or return undef;

    return undef unless($sth->execute(@params));

    while(my $m = $sth->fetchrow_hashref('NAME_lc')) {
        $m->{state} = Vhffs::Functions::status_string_from_status_id($m->{state});
        push(@$mys, $m);
    }

    return $mys;
}




sub create_mysql($$$$$$$)
{
    my( $main , $dbname , $user , $group , $dbuser, $dbpass, $description ) = @_;

    return undef if( ! defined $user );
    return undef if( ! defined $group );

    
    my $mysql = Vhffs::Services::Mysql::create($main, $dbname, $dbuser, $dbpass, $description, $user, $group);

    return undef unless( defined $mysql );

    return undef if ( Vhffs::Acl::add_acl( $user , $mysql , Vhffs::Constants::ACL_DELETE , $main ) < 0 );
    return undef if ( Vhffs::Acl::add_acl( $group , $mysql , Vhffs::Constants::ACL_VIEW , $main ) < 0 );

    return $mysql;
}

=pod

=head2 getall_per_group

    $mysql = Vhffs::Panel::Mysql::getall_per_group($vhffs, $gid);

Returns an array of hashrefs (oid, displayname, active, state (localized string)) of all MySQL DBs owned by
a given group.

=cut


sub getall_per_group
{
    my ( $main, $gid ) = @_;

    my $dbh = $main->get_db_object;
    my $sql = 'SELECT m.object_id AS oid, m.dbname AS displayname, o.state FROM vhffs_mysql m INNER JOIN vhffs_object o ON m.object_id = o.object_id WHERE o.owner_gid = ? ORDER BY m.dbname';
    my $sth = $dbh->prepare($sql) or return -1;
    $sth->execute($gid) or return -2;
    my $mysql = [];
    while(my $m = $sth->fetchrow_hashref) {
        $m->{active} = ($m->{state} == Vhffs::Constants::ACTIVATED);
        $m->{refused} = ($m->{state} == Vhffs::Constants::VALIDATION_REFUSED);
        $m->{state} = Vhffs::Functions::status_string_from_status_id($m->{state});
        push @$mysql, $m;
    }
    return $mysql;
}

1;
