#!%PERL% -w 
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;
use Encode;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Object;
use Vhffs::ObjectFactory;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $cgi          = $panel->{'cgi'};
my $vhffs        = $panel->{'vhffs'};
my $user         = $panel->{'user'};
my $templatedir  = $panel->{'templatedir'};

my $accept       = $cgi->param('ACCEPT');
my $reason       = Encode::decode_utf8( $cgi->param('reason') );

my $template     = new HTML::Template( filename => $templatedir.'/panel/admin/misc/moderation_applied.tmpl' );

#Use is not allowed to see this page, only MODERATOR and ADMIN
unless( $user->is_moderator || $user->is_admin )
{
	my $message = gettext('You\'re not allowed to do this (ACL rights)');
	$template->param( MESSAGE => $message );
}
else
{
	my $oid = $cgi->param('OID');
	my $object = Vhffs::ObjectFactory::fetch_object( $vhffs , $oid );

	if( ( ! defined $oid ) || ( ! defined $object ) || ( ! defined $accept ) )
	{
		$template->param( MESSAGE  => gettext("CGI Error !") );
	}
	else
	{
		my $ok;

		if( $accept == 1 )
		{
			$ok = $object->moderate_accept;
		}
		else
		{
			$ok = $object->moderate_refuse( $reason );
		}
		
		if( $ok < 0 )
		{
			$template->param( MESSAGE  => gettext("Cannot apply modifications") );
		}
		else
		{
			$template->param( MESSAGE  => gettext("Modifications applied successfully") );
		}
	}
}

$panel->set_refresh_url( '/admin/moderation.pl' );
$panel->build( $template );
$panel->display;
