#!%PERL% -w 
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;
use HTML::Template;
use Locale::gettext;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::Panel::Main;
use Vhffs::Panel::Svn;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $vhffs = $panel->{'vhffs'};
my $user = $panel->{'user'};
my $cgi = $panel->{'cgi'};
my $templatedir = $panel->{'templatedir'};
my $template;

if( ($user->is_moderator != 1 ) && ( $user->is_admin != 1 ) )
{
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext('You are not allowed to see it') );
}
else
{
	$template = new HTML::Template( filename => $templatedir.'/panel/admin/misc/list.tmpl' );
	my $name = $cgi->param('NAME');
	if( defined( $name ) )
	{
		$template->param( TITLE => gettext('Search result for Subversion repository').': '.$name );
	}
	else
	{
		$template->param( TITLE => gettext('All Subversion repositories lists') );
	}

	$template->param(TEXT_TITLE1 => gettext('SVN root'));
	$template->param(TEXT_TITLE2 => gettext('Group'));
	$template->param(TEXT_TITLE3 => gettext('State'));

	my $repos = Vhffs::Panel::Svn::search( $vhffs, $name );
	if( defined $repos )
	{
		my $subtemplate = new HTML::Template( filename => $templatedir.'/panel/admin/svn/part.tmpl', global_vars => 1 );
		if( $user->is_admin == 1 )  {
			$subtemplate->param( ACTION => gettext('Modify') );
		}  else  {
			$subtemplate->param( ACTION => gettext('Show') );
		}

		$subtemplate->param( SVNREPOS => $repos);
		$template->param( LIST => $subtemplate->output );
	}
}

$panel->build( $template );
$panel->display;
