#!%PERL% -w 
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use strict;


use lib '%VHFFS_LIB_DIR%';
use Vhffs::Panel::Admin;
use Vhffs::Panel::Main;
use Vhffs::Panel::Template;
use Vhffs::Tag::Category;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

$panel->check_modo;

my $cgi = $panel->{cgi};
my $category;
my $template;
my $templatedir = $panel->{templatedir};
my $user = $panel->{user};

if(!defined $cgi->param('category_id')) {
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext('CGI Error!') );
} elsif(!defined($category = Vhffs::Tag::Category::get_by_category_id($panel->{vhffs}, $cgi->param('category_id')))) {
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext('Category not found!') );
} else {
	if(defined $cgi->param('update_tag_category_submit')) {
		if(update()) {
			$panel->add_info( gettext('Tag category successfully updated') );
		} else {
			$panel->add_error( gettext('Unable to update category') )
		}
	}
	
	$template = new Vhffs::Panel::Template(filename => $templatedir.'/panel/admin/tag/category/edit.tmpl');
	
	$panel->set_title(gettext('Update Tag Category'));
	
	$template->param( LABEL_TEXT => gettext('Label') );
	$template->param( DESCRIPTION_TEXT => gettext('Description') );
	$template->param( VISIBILITY_TEXT => gettext('Visibility') );
	$template->param( VISIBILITIES => [
		{ CODE => Vhffs::Constants::TAG_VISIBILITY_GROUP_CREATION, LABEL => gettext('Public (available on group creation)') },
		{ CODE => Vhffs::Constants::TAG_VISIBILITY_PUBLIC, LABEL => gettext('Public') },
		{ CODE => Vhffs::Constants::TAG_VISIBILITY_MODERATORS, LABEL => gettext('Moderators') },
		{ CODE => Vhffs::Constants::TAG_VISIBILITY_ADMINS, LABEL => gettext('Administrators') }
	]);
	$template->param( UPDATE_TEXT => gettext('Update') );
	$template->param( LABEL_VALUE => $category->{label} );
	$template->param( DESCRIPTION_VALUE => $category->{description} );
	$template->param( VISIBILITY_VALUE => $category->{visibility} );
	$template->param( CATEGORY_ID_VALUE => $category->{category_id} );
	
}
$panel->build( $template );
$panel->display;


sub update {
	my $vhffs = $panel->{vhffs};
	my $label = $cgi->param('label');
	my $description = $cgi->param('description');
	my $visibility = $cgi->param('visibility');
	
	if(!(defined $label && defined $description && defined $visibility)) {
		$panel->add_error( gettext('CGI error') );
		return 0;
	}
	
	if($label =~ /^\s*$/) {
		$panel->add_error( gettext('You have to enter a label') );
	}
	
	if($description =~ /^\s*$/) {
		$panel->add_error( gettext('You have to enter a description') );
	}
	
	if($visibility !~ /^\d+$/) {
		$panel->add_error( gettext('Invalid visibility') );
	}
	
	if($panel->has_errors()) {
		return 0;
	}
	
	
	$category->{label} = $label;
	$category->{description} = $description;
	$category->{visibility} = $visibility;
	$category->{updated} = time();
	$category->{updater_id} = $user->get_uid;
	return $category->save();
}
