#!%PERL% -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use utf8;
use POSIX qw(locale_h);
use locale;
use Locale::gettext;
use strict;


use lib '%VHFFS_LIB_DIR%';
use Vhffs::Panel::Main;
use Vhffs::Panel::Admin;
use Vhffs::Panel::Template;
use Vhffs::Tag::Category;
use Vhffs::Tag;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

$panel->check_modo;

my $cgi = $panel->{cgi};

if(defined $cgi->param('create_tag_submit')) {
	if(create()) {
		$panel->redirect('/admin/tag/index.pl?msg='.gettext('Tag successfully created'));
		exit(0);
	}
}

my $templatedir = $panel->{templatedir};

my $template = new Vhffs::Panel::Template(filename => $templatedir.'/panel/admin/tag/create.tmpl', die_on_bad_params => 0);

$panel->set_title(gettext('Create Tag'));

$template->param( CATEGORY_TEXT => gettext('Category') );
$template->param( CATEGORIES => Vhffs::Tag::Category::get_all($panel->{vhffs}) );
$template->param( LABEL_TEXT => gettext('Label') );
$template->param( DESCRIPTION_TEXT => gettext('Description') );
$template->param( CREATE_TEXT => gettext('Create') );

$panel->build( $template );
$panel->display;


sub create {
	my $category_id = $cgi->param('category_id');
	my $label = $cgi->param('label');
	my $description = $cgi->param('description');
	my $main = $panel->{vhffs};
	
	unless(defined $category_id && defined $label && defined $description) {
		$panel->add_error( gettext('CGI Error!') );
		return 0;
	}
	
	if($category_id !~ /^\d+$/) {
		$panel->add_error( gettext('Invalid category') );
		return 0;
	}
	
	if($label =~ /^\s*$/) {
		$panel->add_error( gettext('You have to enter a label') );
		return 0;
	}
	
	if($description =~ /^\s*$/) {
		$panel->add_error( gettext('You have to enter a description') );
		return 0;
	}
	
	my $category = Vhffs::Tag::Category::get_by_category_id($main, $category_id);
	
	unless(defined $category) {
		$panel->add_error( gettext('Category does not exists') );
		return 0;
	}
	
	unless(defined Vhffs::Tag::create($main, $label, $description, $panel->{user}, $category)) {
		$panel->add_error( gettext('Unable to create tag') );
	}
	
	return 1;
}