#!%PERL% -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use Encode;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::Group;
use Vhffs::Services::Cron;
use Vhffs::Panel::Cron;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $vhffs = $panel->{vhffs};
my $templatedir = $panel->{templatedir};
my $cgi = $panel->{cgi};
my $user = $panel->{user};
my $group = Vhffs::Group::get_by_groupname( $vhffs , $cgi->param('group') );

unless( defined $group && $user->can_modify( $group ) ) {
	my $template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext( 'You\'re not allowed to do this (ACL rights)' ) );

	$panel->build( $template );
	$panel->display;
}
else  {
	my $submitted = defined($cgi->param('cron_submit'));
	my $cronpath = '';
	my $interval = '';
	my $reportmail = '';
	my $description = '';

	if( $submitted ) {
		$cronpath = $cgi->param('cronpath');
		$interval = $cgi->param('interval');
		$reportmail = $cgi->param('reportmail');
		$description = Encode::decode_utf8( $cgi->param('description') );

		unless( defined $cronpath && defined $interval && defined $reportmail && defined $description ) {
			$panel->add_error( gettext('CGI Error !') );
		} elsif($description =~ /^\s*$/) {
			$panel->add_error( gettext('You must enter a description') );
		} elsif(!Vhffs::Services::Cron::check_cronpath($cronpath)) {
			$panel->add_error( gettext('Invalid cronpath, it must contain only letters, numbers, underscore, dash, dot or slash. A valid cronpath will be something like /home/group/script.sh)') );
		} elsif( $interval !~ /^\d+$/ || $interval <= 0 )  {
			$panel->add_error( gettext('Invalid interval, it must be a positive integer') );
		} elsif( $reportmail ne ''  &&  !Vhffs::Functions::valid_mail( $reportmail )  )  {
			$panel->add_error( gettext('The email you entered fails syntax check') );
		} elsif(defined Vhffs::Panel::Cron::create_cron($vhffs, $cronpath, $interval*60, $reportmail , $description, $user, $group)) {
			my $url = '/group/view.pl?group='.$group->get_groupname.'&msg='.gettext('The Cron job was successfully created !');
			$panel->redirect($url);
		} else {
			$panel->add_error( 'An error occured while creating the object.' );
		}
	}

	if( !$submitted || $panel->has_errors() ) {
		my $template = new HTML::Template( filename => $templatedir.'/panel/cron/create.tmpl' );

		$panel->set_title( gettext('Create a Cron job') );

		$template->param( GROUP_NAME => gettext('Group owning this cron job') );
		$template->param( TEXT_CRONPATH_LABEL => gettext('Path') );
		$template->param( TEXT_CRONPATH_HELP => gettext('Absolute path of the command to run') );
		$template->param( TEXT_INTERVAL_LABEL => gettext('Interval') );
		$template->param( TEXT_INTERVAL_HELP => sprintf(gettext('In minutes, at which interval this cron should be started, the minimum interval is set to %d minutes'), $vhffs->get_config->get_service('cron')->{'minimum_interval'}) );
		$template->param( TEXT_REPORTMAIL_LABEL => gettext('Mail to') );
		$template->param( TEXT_REPORTMAIL_HELP => gettext('Email to which report will be sent if something went wrong') );
		$template->param( CRONPATH_VALUE => $cronpath );
		$template->param( INTERVAL_VALUE => $interval );
		$template->param( REPORTMAIL_VALUE => $reportmail );
		$template->param( GROUP => $group->get_groupname );
		$template->param( SEND => gettext('Send') );
		$template->param( DESCRIPTION => gettext('Description') );
		$template->param( DESCRIPTION_VALUE => $description );

		$panel->build( $template );
		$panel->display;
	}
}
