#!%PERL% -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::Object;
use Vhffs::Panel::Template;
use Vhffs::Services::Cron;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $vhffs = $panel->{'vhffs'};
my $user = $panel->{'user'};
my $cgi = $panel->{'cgi'};
my $templatedir = $panel->{'templatedir'};

my $cronpath = $cgi->param('name');
my $cron = Vhffs::Services::Cron::get_by_cronpath( $vhffs , $cronpath );
my $template;


unless( defined $cronpath )
{
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext( 'CGI Error !' ) );
}
elsif( ! defined $cron )
{
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext('Cannot get informations on this object') );
}
elsif( !$user->can_view( $cron ) )
{
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext( 'You\'re not allowed to do this, object is not in active state or you don\'t have enough ACL rights' ) );
}
else
{
	if( defined $cgi->param('save_prefs_submit') ) {
		save_prefs();
	}

	$template = new Vhffs::Panel::Template( filename => $templatedir."/panel/cron/prefs.tmpl" );

	$panel->set_title( gettext("Cron job Administration") );

	$template->param( TEXT_CRONPATH => gettext("Path") );
	$template->param( VALUE_CRONPATH => $cron->get_cronpath );

	$template->param( TEXT_INTERVAL => gettext("Interval between runs") );
	$template->param( VALUE_INTERVAL => $cron->get_interval/60 );
	$template->param( TEXT_MINUTES => gettext("minutes") );

	$template->param( TEXT_REPORTMAIL => gettext("Mail reports to") );
	$template->param( VALUE_REPORTMAIL => $cron->get_reportmail );

	use DateTime;
	use DateTime::Locale;
	my $loc = DateTime::Locale->load($user->get_lang);
	my $dt;
	my $datestr;

	if( defined $cron->get_lastrundate )  {
		$dt = DateTime->from_epoch( epoch => $cron->get_lastrundate, locale => $user->get_lang);
		$datestr = $dt->strftime($loc->medium_date_format()).' '.$dt->strftime($loc->long_time_format());
	} else {
		$datestr = gettext('Never');
	}
	$template->param( TEXT_LASTRUNDATE => gettext("Last run date was") );
	$template->param( VALUE_LASTRUNDATE => $datestr );

	my $rt = $cron->get_lastrunreturncode;
	$rt = gettext('Never') unless defined $rt;
	$template->param( TEXT_LASTRUNRETURNCODE => gettext("Last run return code was") );
	$template->param( VALUE_LASTRUNRETURNCODE => $rt );

	if( defined $cron->get_nextrundate )  {
		$dt = DateTime->from_epoch( epoch => $cron->get_nextrundate, locale => $user->get_lang);
		$datestr = $dt->strftime($loc->medium_date_format()).' '.$dt->strftime($loc->long_time_format());
	} else {
		$datestr = gettext('As soon as possible');
	}
	$template->param( TEXT_NEXTRUNDATE => gettext("Next run is scheduled at") );
	$template->param( VALUE_NEXTRUNDATE => $datestr );

	$template->param( TEXT_RUNNING => gettext("State") );
	my $state = $cron->get_running;
	my $statestr = '';
	if( $state == 0 ) {
		$statestr = gettext('Sleeping');
	} elsif( $state == 1 ) {
		$statestr = gettext('Running');
	} else {
		$statestr = gettext('Collided, something went wrong, recovering');
	}
	$template->param( VALUE_RUNNING => $statestr );

	$template->param( VALUE_OID => $cron->get_oid );
	$template->param( TEXT_ACL_ADMIN => gettext("Admin Rights on this object (ACL)") );
	$template->param( EXPLAIN_ADMIN_ACL => gettext("You can Manage rights on this service for each user in the VHFFS database. Please read help before manage it.") );
	$template->param( ADMIN_ACL => gettext("Ok, go to ACL admin") );

	$template->param( TEXT_SEND => gettext("Modify") );
	$template->param( TEXT_DELETE_CRON => gettext("Delete this cron job") );
	$template->param( TEXT_BEFORE_DELETE => gettext("This action is non-reversible. This Cron job will be DESTROYED.") );
	$template->param( ASK_DELETE_CRON => gettext("Are you SURE you want DELETE this Cron job ?") );
	$template->param( YES => gettext("Yes I'm sure of what I do") );
	$template->param( NO => gettext("No, I'm not sure, I prefer to keep this project.") );
	$template->param( TEXT_DELETE => gettext("Delete") );

	my $adminpart = Vhffs::Panel::Object::admin_part( $panel, $cron );
	$template->param( ADMIN_PART => $adminpart->output ) if( defined $adminpart );
}

$panel->build( $template );
$panel->display;

sub save_prefs {
	my $ok = 1;

	unless( $user->can_modify($cron) ) {
		$panel->add_error( gettext('You\'re not allowed to do this, object is not in active state or you don\'t have enough ACL rights') );
		return 1;
	}

	my $interval = $cgi->param('interval');
	my $reportmail = $cgi->param('reportmail');
	unless( defined $interval && defined $reportmail ) {
		$panel->add_error( gettext('CGI Error !') );
		return 1;
	}

	$cron->set_interval( $interval*60 );
	if( $cron->set_reportmail( $reportmail ) ) {
		$panel->add_error( gettext('The email you entered fails syntax check') );
		$ok = 0;
	}

	if( $ok )  {
		if( $cron->commit < 0)  {
			$panel->add_error( gettext('Unable to apply changes') );
			return 1;
		}
		$panel->add_info( gettext('Cron job successfully updated') );
		return 0;
	}

	return 1;
}
