#!%PERL% -w
# Copyright (c) vhffs project and its contributors
# Copyright (c) 2007 Julien Danjou <julien@danjou.info>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use Encode;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::Group;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $vhffs = $panel->{vhffs};
my $templatedir = $panel->{templatedir};
my $cgi = $panel->{cgi};
my $user = $panel->{user};
my $group = Vhffs::Group::get_by_groupname( $vhffs , $cgi->param('group') );

unless( defined $group && $user->can_modify( $group ) ) {
	my $template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext( 'You\'re not allowed to do this (ACL rights)' ) );

	$panel->build( $template );
	$panel->display;
}
else {
	my $submitted = $cgi->param('git_submit');
	my $reponame = '';
	my $description = '';

	if( $submitted ) {
		$reponame = $cgi->param('reponame');
		my $fullreponame = $group->get_groupname.'/'.$reponame.'.git';
		$description = Encode::decode_utf8( $cgi->param('description') );
		unless( defined $reponame && defined $description ) {
			$panel->add_error( gettext('CGI Error !') );
		} elsif( !Vhffs::Services::Git::check_name($fullreponame) ) {
			$panel->add_error( gettext('Invalid reponame. It must contain between 3 and 64 characters, only lowercase letters and numbers') );
		} elsif( $description =~ /^\s*$/) {
			$panel->add_error( gettext('You must enter a description') );
		} elsif( defined Vhffs::Panel::Git::create_git( $vhffs, $fullreponame, $description, $user, $group ) ) {
			my $url = '/group/view.pl?group='.$group->get_groupname.'&msg='.gettext('The GIT object was successfully created !');
			$panel->redirect($url);
		} else {
			$panel->add_error( gettext('An error occured while creating the git repository') );
		}
	}

	if( !$submitted || $panel->has_errors ) {
		my $template = new HTML::Template( filename => $templatedir.'/panel/git/create.tmpl' );
	
		$panel->set_title( gettext('Create a git Repository') );
		$template->param( REPOSITORY_NAME => gettext('Repository Name') );
		$template->param( REPOSITORY_VALUE => $reponame );
		$template->param( GROUP_NAME => gettext('Group owning this git repository') );

		$template->param( GROUP => $group->get_groupname );
		$template->param( GIT_SUFFIX => '.git' );
		$template->param( SEND => gettext('Send') );
		$template->param( DESCRIPTION => gettext('Description') );
		$template->param( DESCRIPTION_VALUE => $description );

		$panel->build( $template );
		$panel->display;
	}
}
