#!%PERL% -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;


use lib '%VHFFS_LIB_DIR%';
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Services::MailingList;
use Vhffs::Acl;
use Vhffs::Constants;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $vhffs = $panel->{'vhffs'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $cgi = $panel->{'cgi'};
my $domain = $cgi->param("domain");
my $lpart = $cgi->param("local");
my $sure = $cgi->param("DELETE");
my $template;
my $subtemplate;
my $message; 

my $templatedir = $vhffs->get_config->get_templatedir;

my $list = Vhffs::Services::MailingList::get_by_mladdress( $vhffs , $lpart , $domain );

$template = new HTML::Template( filename => $templatedir."/panel/misc/simplemsg.tmpl" );

if( ! defined $sure )
{
	$message = gettext( "CGI Error !" );
}
elsif( ! defined $list )
{
	$message = gettext( "Cannot get informations on this object");
}
elsif( $list->get_status != Vhffs::Constants::ACTIVATED )
{
	$message = gettext( "This object is not functionnal yet. Please wait creation or moderation.");
}
elsif( !$user->can_delete( $list ) ) 
{
	$message = gettext( 'You\'re not allowed to do this, object is not in active state or you don\'t have enough ACL rights' );
}
elsif( $sure == 0 )
{
	$message = gettext( "List will NOT be deleted" );
}
else
{
	$list->set_status( Vhffs::Constants::TO_DELETE );

	if( $list->commit < 0 )
	{
		$message = gettext( "Cannot commit changes on this object, will NOT be deleted" );
	}
	else
	{
		$message = gettext( "Will be DELETED in a few minutes" );
	}

}



$template->param( MESSAGE => $message );

$panel->build( $template );
$panel->display;
