#!%PERL% -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::Object;
use Vhffs::Panel::Template;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $vhffs = $panel->{'vhffs'};
my $user = $panel->{'user'};
my $cgi = $panel->{'cgi'};
my $templatedir = $panel->{'templatedir'};

my $dbname = $cgi->param('name');
my $mysql = Vhffs::Services::Mysql::get_by_dbname( $vhffs , $dbname );
my $group = Vhffs::Group::get_by_gid( $vhffs , $mysql->{'owner_gid'} );

my $template;


unless( defined $dbname )
{
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext( 'CGI Error !' ) );
}
elsif( ! defined($mysql) )
{
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext('Cannot get informations on this object') );
}
elsif( !$user->can_view( $mysql ) )
{
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext( 'You\'re not allowed to do this, object is not in active state or you don\'t have enough ACL rights' ) );
}
else
{

    if(defined($cgi->param('save_prefs_submit'))) {
        if(save_prefs()) {
        # If successful, save_prefs issues a redirect.
            exit;
        }
    }
	$template = new Vhffs::Panel::Template( filename => $templatedir."/panel/mysql/prefs.tmpl" );

	$panel->set_title( gettext("MySQL Administration") );

	$template->param( TEXT_DBNAME => gettext("Name of the database") );
	$template->param( VALUE_DBNAME => $mysql->get_dbname );

	$template->param( TEXT_DBUSER => gettext("Username for this database") );
	$template->param( VALUE_DBUSER => $mysql->get_dbname );

	$template->param( TEXT_DBPASS => gettext("Password for this database") );
	#$template->param( VALUE_DBPASS => $mysql->get_dbpassword );

	$template->param( VALUE_OID => $mysql->get_oid );
	$template->param( TEXT_ACL_ADMIN => gettext("Admin Rights on this object (ACL)") );
	$template->param( EXPLAIN_ADMIN_ACL => gettext("You can Manage rights on this service for each user in the VHFFS database. Please read help before manage it.") );
	$template->param( ADMIN_ACL => gettext("Ok, go to ACL admin") );

	$template->param( TEXT_SEND => gettext("Modify") );
	$template->param( TEXT_DELETE_MYSQL => gettext("Delete this database") );
	$template->param( TEXT_BEFORE_DELETE => gettext("This action is non-reversible. This MySQL database will be DESTROYED.") );
	$template->param( ASK_DELETE_MYSQL => gettext("Are you SURE you want DELETE this MySQL database ?") );
	$template->param( YES => gettext("Yes I'm sure of what I do") );
	$template->param( NO => gettext("No, I'm not sure, I prefer to keep this project.") );
	$template->param( TEXT_DELETE => gettext("Delete") );

	my $adminpart = Vhffs::Panel::Object::admin_part( $panel, $mysql );
	$template->param( ADMIN_PART => $adminpart->output ) if( defined $adminpart );
}

$panel->build( $template );
$panel->display;

sub save_prefs {
    if(!$user->can_modify($mysql)) {
        $panel->add_error( gettext('You\'re not allowed to do this, object is not in active state or you don\'t have enough ACL rights') );
        return 0;
    }

    my $new_passwd = $cgi->param('newpassword');
    if(!defined $new_passwd) {
        $panel->add_error( gettext('CGI Error !') );
        return 0;
    }

    if($mysql->set_dbpassword($new_passwd) < 0) {
        $panel->add_error( gettext('Bad password, should be at least 3 chars') );
        return 0;
    } else {
        $mysql->set_status( Vhffs::Constants::WAITING_FOR_MODIFICATION);
        if($mysql->commit < 0) {
            $panel->add_error( gettext('Unable to apply changes') );
            $mysql->blank_password;
            return 0;
        } else {
            my $url = '/group/view.pl?group='.$group->get_groupname.'&msg='.gettext('Password change request taken in account, please wait for processing');
            $panel->redirect($url);
            return 1;
        }
    }
}
