#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;


use lib '%VHFFS_LIB_DIR%';
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::Object;
use Vhffs::Panel::Template;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $vhffs = $panel->{'vhffs'};
my $cgi = $panel->{'cgi'};
my $user = $panel->{'user'};
my $templatedir = $panel->{'templatedir'};

my $repo_name = $cgi->param('name');
my $repo = Vhffs::Services::Repository::get_by_reponame( $vhffs , $repo_name );
my $template;

unless( defined $repo_name ) {
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext('CGI Error !') );
} elsif( ! defined $repo ) {
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext('Cannot get informations on this object') );
} elsif( !$user->can_view( $repo ) ) {
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext( 'You\'re not allowed to do this, object is not in active state or you don\'t have enough ACL rights' ) );
} else {
    if(defined($cgi->param('update_quota_submit'))) {
        update_quota();
    }
	$template = new Vhffs::Panel::Template( filename => $templatedir."/panel/repository/prefs.tmpl" );

	$panel->set_title( gettext('Admin Download repository') );
	$template->param( TEXT_REPONAME => $repo->get_name );

	$template->param( THEME => $panel->{theme} );
	$template->param( QUOTA_VALUE => sprintf( gettext("Quota (used/total) : %s/%s") , $repo->get_quota_used , $repo->get_quota ) );
	$template->param( QUOTA_WIDTH => ( ($repo->get_quota_used / $repo->get_quota) * 300 ) );

	$template->param( TEXT_DELETE_REPOSITORY => gettext("Delete this project") );
	$template->param( TEXT_BEFORE_DELETE => gettext("This action is non-reversible. This download repository will be DESTROYED.") );
	$template->param( ASK_DELETE_REPOSITORY => gettext("Are you SURE you want DELETE this download repository ?") );
	$template->param( YES => gettext("Yes I'm sure of what I do") );
	$template->param( NO => gettext("No, I'm not sure, I prefer to keep this project.") );
	$template->param( TEXT_DELETE => gettext("Delete") );

	$template->param( VALUE_OID => $repo->get_oid );
	$template->param( TEXT_ACL_ADMIN => "Admin Rights on this object (ACL)" );
	$template->param( EXPLAIN_ADMIN_ACL => "You can Manage rights on this service for each user in the VHFFS database. Please read help before manage it." );
	$template->param( ADMIN_ACL => "Ok, go to ACL admin" );

	if($user->is_admin() == 1) {
		$template->param( ADMIN => 1);
		my $adminpart = Vhffs::Panel::Object::admin_part( $panel, $repo );
		$template->param( ADMIN_PART => $adminpart->output ) if( defined $adminpart );
		$template->param( QUOTA => $repo->get_quota() );
		$template->param( USED_QUOTA => $repo->get_quota_used() );
	}
}

$panel->build( $template );
$panel->display;

sub update_quota {
    unless($user->is_admin()) {
        $panel->add_error( gettext('Only administrators are allowed to do this') );
        return;
    }
    
    my $quota = $cgi->param('new_quota');
    unless(defined $quota && $quota =~ /^\d+$/) {
        $panel->add_error( gettext('Invalid quota') );
        return;
    }
    
    $repo->set_quota($quota);

    if($repo->commit < 0) {
        $panel->add_error( gettext('Unable to apply modifications, please try again later') );
    } else {
        $panel->add_info( gettext('Repository updated, please wait while quota is updated on filesystem') );
    }
}
