#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::User;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::Object;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $vhffs = $panel->{'vhffs'};
my $user = $panel->{'user'};
my $cgi = $panel->{'cgi'};
my $templatedir = $panel->{'templatedir'};

my $repo_name = $cgi->param("name");
my $svn = Vhffs::Services::Svn::get_by_reponame( $vhffs , $repo_name );
my $group = Vhffs::Group::get_by_gid( $vhffs , $svn->{'owner_gid'} );
my $template;

unless( defined $repo_name )
{
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext('CGI Error !') );
}
elsif( !defined $svn )
{
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext('Cannot get informations on this object') );
}
elsif( !$user->can_view( $svn ) )
{
	$template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext( 'You\'re not allowed to do this, object is not in active state or you don\'t have enough ACL rights' ) );
}
else
{
    if(defined $cgi->param('prefs_save_submit')) {
        if(save_prefs()) {
            exit;
        }
    }
    $template = new HTML::Template( filename => $templatedir."/panel/svn/prefs.tmpl" );

    $panel->set_title( gettext("Admin Subversion Repository") );
    
    
    $template->param( TEXT_REPONAME => $svn->get_reponame );
    $template->param( TITLE_PUBLIC => gettext("Public") );
    $template->param( TEXT_PUBLIC => gettext("Is this a public repository ?") );
    $template->param( PUBLIC_YES => gettext("Yes") );
    $template->param( PUBLIC_NO => gettext("No") );
    $template->param( TEXT_SEND => gettext("Modify") );
    $template->param( TEXT_DELETE_CVS => gettext("Delete this repository") );
    $template->param( TEXT_BEFORE_DELETE => gettext("This action is non-reversible. This subversion repository will be DESTROYED.") );
    $template->param( ASK_DELETE_CVS => gettext("Are you SURE you want DELETE this subversion repository ?") );
    $template->param( YES => gettext("Yes I'm sure of what I do") );
    $template->param( NO => gettext("No, I'm not sure, I prefer to keep this project.") );
    $template->param( TEXT_DELETE => gettext("Delete") );

    $template->param( VALUE_OID => $svn->get_oid );
    $template->param( TEXT_ACL_ADMIN => gettext('Admin Rights on this object (ACL)') );
    $template->param( EXPLAIN_ADMIN_ACL => gettext('You can Manage rights on this service for each user in the VHFFS database. Please read help before manage it.') );
    $template->param( ADMIN_ACL => gettext('Ok, go to ACL admin') );

    $template->param( TITLE_OPT => gettext('Options') );
    $template->param( TEXT_OPT_ML => gettext('Notify changes on mailing-list :'));
    $template->param( TEXT_OPT_ML_REMINDER => sprintf( gettext('Don\'t forget to subscribe %s to your mailing list if you are filtering posts') , $vhffs->get_config->get_service('svn')->{notify_from} ) );
    $template->param( TEXT_ML_NAME => $svn->{ml_name} );
    
    if( $svn->is_public == 1 )
    {
            $template->param( YES_SELECTED => "selected" );
    }
    else
    {
            $template->param( NO_SELECTED => "selected" );
    }

	my $adminpart = Vhffs::Panel::Object::admin_part( $panel, $svn );
	$template->param( ADMIN_PART => $adminpart->output ) if( defined $adminpart );
}

$panel->build( $template );
$panel->display;

sub save_prefs {
    my $public = $cgi->param('public');
    my $ml_name = $cgi->param('ml_name');

    if(!$user->can_modify($svn)) {
        $panel->add_error( gettext( 'You\'re not allowed to do this, object is not in active state or you don\'t have enough ACL rights' ) );
        return 0;
    }

    if(!defined $ml_name || !defined $public) {
        $panel->add_error( gettext('CGI Error !') );
        return 0;
    }

    if($public == 1 && !$svn->is_public) {
        $svn->set_public;
        $svn->set_status( Vhffs::Constants::WAITING_FOR_MODIFICATION );
    } elsif($public == 0 && $svn->is_public) {
        $svn->set_status( Vhffs::Constants::WAITING_FOR_MODIFICATION );
        $svn->set_private;
    }

    if(($ml_name =~ /^\s*$/ || Vhffs::Functions::valid_mail($ml_name))) {
        if($ml_name ne $svn->get_ml_name) {
            $svn->set_status( Vhffs::Constants::WAITING_FOR_MODIFICATION );
            $svn->set_ml_name($ml_name);
        }
    } else {
        $panel->add_error( gettext('Mailing list address is invalid') );
        return 0;
    }

    if($svn->get_status == Vhffs::Constants::WAITING_FOR_MODIFICATION) {
        if($svn->commit > 0) {
            my $url = '/group/view.pl?group='.$group->get_groupname.'&msg='.gettext('Modifications applied. Please wait while your repository is being updated');
            $panel->redirect($url);
            return 1;

        } else {
            $panel->add_error( gettext('Unable to update repository') );
            return 0;
        }
    }
}
