#!%PERL% -w
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;
use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use Encode;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Panel::Group;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;
my $session = $panel->get_session;
exit 0 unless $session;

my $vhffs = $panel->{vhffs};
my $templatedir = $panel->{templatedir};
my $cgi = $panel->{cgi};
my $user = $panel->{user};
my $group = Vhffs::Group::get_by_groupname( $vhffs , $cgi->param('group') );

unless( defined $group && $user->can_modify( $group ) ) {
	my $template = new HTML::Template( filename => $templatedir.'/panel/misc/simplemsg.tmpl' );
	$template->param( MESSAGE => gettext( 'You\'re not allowed to do this (ACL rights)' ) );

	$panel->build( $template );
	$panel->display;
}
else  {
	my $submitted = defined($cgi->param('web_submit'));
	my $servername = '';
	my $description = '';

	if( $submitted ) {
		$servername = $cgi->param('servername');
		$description = Encode::decode_utf8( $cgi->param('description') );
		unless( defined $servername  &&  defined $description ) {
			$panel->add_error( gettext('CGI Error !') );
		} elsif( !Vhffs::Functions::check_domain_name($servername) ) {
			$panel->add_error( gettext('Invalid servername (doesn\'t conform to domain names rules)') );
		} elsif( $description =~ /^\s*$/ ) {
			$panel->add_error( gettext('You must enter a description') );
		} elsif( defined(Vhffs::Panel::Web::create_web( $vhffs, $servername, $description, $user, $group)) ) {
			my $url = '/group/view.pl?group='.$group->get_groupname.'&msg='.gettext('The webarea was successfully created !');
			$panel->redirect($url);
		} else {
			$panel->add_error( gettext('Error creating webarea.') );
		}
	} else {
		my $webconfig = $vhffs->get_config->get_service('web');
		$servername = '<'.gettext('new site').'>.'.$webconfig->{'default_domain'} if( defined $webconfig->{'default_domain'} );
	}

	if( !$submitted || $panel->has_errors() ) {
		my $template = new HTML::Template( filename => $templatedir.'/panel/web/create.tmpl' );
		$panel->set_title( gettext('Create a web space') );
		$template->param( SERVERNAME_TEXT => gettext('Address (ServerName directive)') );
		$template->param( SERVERNAME_WARNING => gettext('Be careful, if you want create www.domain.tld, you should create a webspace with domain.tld as servername. VHFFS redirect all request from www.domain.tld to domain.tld') );
		$template->param( SERVERNAME_VALUE => $servername );
		$template->param( GROUP_NAME => gettext('Group owning this web space') );

		$template->param( GROUP => $group->get_groupname );
		$template->param( SEND => gettext('Send') );
		$template->param( DESCRIPTION => gettext('Tell us what the use of this web space will be') );
		$template->param( WARNING_PUBLIC => gettext('Please consider that this description is going to be displayed in the public area. So you have to write it in impersonal form. You should take care to write it with correct grammar and tenses. Take all the time you need to fill it with the best content you are able to do.') ) if $panel->is_public;
		$template->param( DESCRIPTION_VALUE => $description );

		$panel->build( $template );
		$panel->display;
	}
}
