#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

# Public search page for groups.
# Parameters:
# either
#  - included_tags:	ID of the tags that should be matched
#					by results (logical OR)
#  - excluded_tags: ID of the tags that shouldn't be matched
#					by results (logical AND)
#  - groupname: (partial) name of the group
#  - description: (partial) description of the group
#  - start (optional): start page of the search

use strict;
use utf8;

use POSIX qw(locale_h);
use locale;
use Locale::gettext;

use lib '%VHFFS_LIB_DIR%';

use Vhffs::Panel::Group;
use Vhffs::Panel::Public;
use Vhffs::Panel::Commons;

my $panel = new Vhffs::Panel::Public();

my $cgi = $panel->{cgi};

# Tags in "matches" section
my @included_tags_ids = map{ int($_); } $cgi->param('included_tags');
# Tags in "does not match" section
my @excluded_tags_ids = map{ int($_); } $cgi->param('excluded_tags');

my $groupname = Encode::decode_utf8($cgi->param('groupname'));
$groupname = '' unless(defined $groupname);		# Direct tag click brings us here without  without groupname ...
my $description = Encode::decode_utf8($cgi->param('description'));
$description = '' unless(defined $description);	# ... and without description


# current page
my $page = defined($cgi->param('page')) ? int($cgi->param('page')) : 1;

my ($groups, $count) = Vhffs::Panel::Group::public_search($panel->{vhffs}, $groupname, $description, \@included_tags_ids, \@excluded_tags_ids, $page - 1);

if(scalar(@$groups) == 0) {
	$panel->render('common/error.tt', {
		message => gettext('No group found')
	});
	exit(0);
}

my $pager = Vhffs::Panel::Commons::get_pager($page, $count, 10, 5, $panel->{url}, { groupname => $groupname, description => $description, included_tags => \@included_tags_ids, excluded_tags => \@excluded_tags_ids});

my $vars = {
	groups => $groups,
	gs_title => gettext( 'Search results' ),
	gs_pager => $pager
};

$panel->render('content/groupsearch-results.tt', $vars);
