#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;

use POSIX qw(locale_h);
use locale;
use Locale::gettext;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::Panel::Group;
use Vhffs::Panel::Public;

my $panel = new Vhffs::Panel::Public();

my $hostname = $panel->{vhffs}->get_config->get_host_name;

my $vars = {
	lg_title => sprintf( gettext("Last groups on %s") , $hostname ),
	groups => Vhffs::Panel::Group::get_last_groups( $panel->{vhffs} )
};

$panel->render('content/last-groups.tt', $vars);


__END__

use strict;
use utf8;

use POSIX qw(locale_h);
use locale;
use Locale::gettext;
use CGI;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Acl;
use Vhffs::Constants;
use Vhffs::Panel::Main;
use Vhffs::Panel::Template;
use Vhffs::Tag;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;

my $vhffs = $panel->{'vhffs'};
my $templatedir = $panel->{'templatedir'};
my $cgi = $panel->{'cgi'};
my $hostname = $vhffs->get_config->get_host_name;

$panel->check_public();

my $template;
my $subtemplate;

$template = new Vhffs::Panel::Template( filename => $templatedir.'/public/index.tmpl', die_on_bad_params => 0 );

$template->param( TOP_TAGS => Vhffs::Tag::get_most_popular_tags($vhffs) );
$template->param( RANDOM_TAGS => Vhffs::Tag::get_random_tags($vhffs) );

$template->param( TEXT_TITLE => sprintf( gettext("%s public area") , $vhffs->get_config->get_host_name)  );

$template->param( URL_PANEL => $vhffs->get_config->get_panel->{'url'} );

$panel->light( $template );
$panel->display;
