#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;

use lib '%VHFFS_LIB_DIR%';
use utf8;
use Vhffs::Main;
use Vhffs::Constants;
use Vhffs::Services::Cvs;
use Vhffs::Robots;
use HTML::Template;

my $sampleconf = '/usr/lib/vhffs/bots/misc/cvs_viewvc.conf.tmpl';

my $vhffs = init Vhffs::Main;

my $confdir = $vhffs->get_config->get_datadir.'/cvs/conf/';
mkdir( $confdir ) unless -d $confdir;

my $ouputfile = $confdir.'viewvc.conf';


Vhffs::Robots::lock( $vhffs , 'cvs_viewvc' );

my $cvsroots;

if( $vhffs->get_config->get_service_availability('cvs') == 1 )
{
	my $cvss = Vhffs::Services::Cvs::getall( $vhffs , Vhffs::Constants::ACTIVATED );
	foreach my $cvs ( @{$cvss} )
	{
		if( $cvs->is_public == 1 )
		{
			my $cvspath = $cvs->get_cvsroot;
			$cvspath =~ s/\//_/;
			$cvsroots .= '  '.$cvspath.': '.$cvs->get_dir.",\n";
		}
	}
}

if( $cvsroots )  {
	my $template = new HTML::Template( filename => $sampleconf );
	$template->param( CVSROOTS => $cvsroots );

	open( OUTPUT , '>'.$ouputfile );
	print OUTPUT $template->output;
	close( OUTPUT );
}

Vhffs::Robots::unlock( $vhffs , 'cvs_viewvc' );
