#!%PERL%

# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use lib '%VHFFS_LIB_DIR%';
use utf8;
use Vhffs::Services::DNS;
use Vhffs::Robots;
use Vhffs::Main;

use strict;

#Init VHFFS subsystem
my $vhffs = init Vhffs::Main;


#Lock if specified in the config-file
Vhffs::Robots::lock( $vhffs , "dns" );

#Get all DNS objects to create
my $tocreate = Vhffs::Services::DNS::getall( $vhffs , Vhffs::Constants::WAITING_FOR_CREATION );
my $dns;

if( defined $tocreate )
{
	foreach $dns ( @{$tocreate} )
	{
        $dns->set_status( Vhffs::Constants::ACTIVATED );
        if( $dns->commit > 0 )
		{
			Vhffs::Robots::vhffs_log( sprintf( "Create domain %s" , $dns->get_domain  ) , $vhffs);
		}
		else
		{
			Vhffs::Robots::vhffs_log( sprintf( "Cannot create domain %s" , $dns->get_domain  ) , $vhffs);
		}

	}
}

Vhffs::Robots::unlock( $vhffs , "dns" );

exit 0;
