#!%PERL%
# Copyright (c) vhffs project and its contributors
# Copyright (c) 2007 Julien Danjou <julien@danjou.info>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::Main;
use Vhffs::Robots;
use Vhffs::Robots::Git;
use Vhffs::Services::Git;
use Vhffs::Constants;


my $vhffs = init Vhffs::Main;

Vhffs::Robots::lock( $vhffs , 'git' );

my $repos = Vhffs::Services::Git::getall( $vhffs , Vhffs::Constants::TO_DELETE );
foreach my $git ( @{$repos} )
{
	if( Vhffs::Robots::Git::delete_repo( $git ) != 0 )	{
		Vhffs::Robots::vhffs_log( sprintf( 'Cannot delete files from GIT repository %s' , $git->get_reponame ), $vhffs);
	} else {
		Vhffs::Robots::vhffs_log( sprintf( 'Delete files from GIT repository %s' , $git->get_reponame ), $vhffs);
	}

	if( $git->delete < 0 ) {
		Vhffs::Robots::vhffs_log( sprintf( 'Cannot delete GIT repository object %s' , $git->get_reponame ), $vhffs);
	} else {
		Vhffs::Robots::vhffs_log( sprintf( 'Delete GIT repository object %s' , $git->get_reponame ), $vhffs);
	}
}

Vhffs::Robots::unlock( $vhffs , 'git' );
exit 0;
