#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::Robots::Group;
use Vhffs::Main;
use Vhffs::Group;
use Vhffs::Constants;
use Vhffs::Robots;


my $vhffs = init Vhffs::Main;

Vhffs::Robots::lock( $vhffs , 'usergroup' );

my $groups = Vhffs::Group::getall( $vhffs , Vhffs::Constants::TO_DELETE );
foreach my $group ( @{$groups} )
{
	if( $group->is_empty )  {
		Vhffs::Robots::vhffs_log( sprintf( 'Deleted group %s' , $group->get_groupname ), $vhffs);
		Vhffs::Robots::Group::delete( $vhffs , $group );
	}
	else {
		foreach my $object ( @{$group->getall_objects} )
		{
			if( $group->get_oid != $object->get_oid  &&  $object->get_status != Vhffs::Constants::TO_DELETE)  {
				$object->set_status( Vhffs::Constants::TO_DELETE );
				$object->commit;
			}
		}

		Vhffs::Robots::vhffs_log( sprintf( 'Cannot delete group %s, items are remaining, delete status have been set to those items' , $group->get_groupname ), $vhffs);
	}
}

Vhffs::Robots::unlock( $vhffs , 'usergroup' );

exit( 0 );
