#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

#This robot create mail boxes

use strict;
use utf8;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::Services::Mail;
use Vhffs::Robots::Mail;
use Vhffs::Robots;
use Vhffs::Main;

my $vhffs = init Vhffs::Main;
die('Unable to initialize VHFFS main object') unless defined $vhffs;
my $mailconf = $vhffs->get_config->get_service('mail');
die('Unable to find mail configuration (boxes_uid/boxes_gid)') unless ( defined $mailconf && defined $mailconf->{'boxes_uid'} && $mailconf->{'boxes_gid'} );

Vhffs::Robots::lock( $vhffs , 'mail' );

my $boxes = Vhffs::Robots::Mail::getall_boxes( $vhffs , Vhffs::Constants::WAITING_FOR_CREATION );
foreach my $b ( @{$boxes} )
{
	my $mail = Vhffs::Services::Mail::get_by_mxdomain( $vhffs, $b->{domain} );
	if( defined $mail )  {

		my $dir = $mail->get_box_dir( $b->{local_part} );
		Vhffs::Functions::create_dir( $dir );
		if( -d $dir )  {
			Vhffs::Functions::create_dir( $dir.'/Maildir' );
			Vhffs::Functions::create_dir( $dir.'/Maildir/cur' );
			Vhffs::Functions::create_dir( $dir.'/Maildir/new' );
			Vhffs::Functions::create_dir( $dir.'/Maildir/tmp' );
			Vhffs::Functions::chmod_recur( $dir , 0600 , 0700 );
			Vhffs::Functions::change_owner_recur( $dir , $mailconf->{'boxes_uid'} , $mailconf->{'boxes_gid'} );

			$mail->set_box_status( $b->{local_part} , Vhffs::Constants::ACTIVATED );
		} else  {
			$mail->set_box_status( $b->{local_part} , Vhffs::Constants::CREATING_ERROR );
		}
	}
}

Vhffs::Robots::unlock( $vhffs , 'mail' );


exit 0;
