#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

########################################################
# This robot make dump for each MySQL database
# and put it on each group directory
#

use strict;
use utf8;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::Main;
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Functions;
use Vhffs::Services::Mysql;
use Vhffs::Robots;

my $vhffs = init Vhffs::Main; 

Vhffs::Robots::lock( $vhffs , 'dumpmysql' );

my $mysqlconf = $vhffs->get_config->get_service('mysql');
die 'Error, mysqldump is not present on this system in path "'.$mysqlconf->{'mysqldump_path'}.'"'."\n" unless( -x $mysqlconf->{'mysqldump_path'} );

umask 0337;

my $objs  = Vhffs::Services::Mysql::getall( $vhffs , Vhffs::Constants::ACTIVATED , undef , undef );
foreach my $obj ( @{$objs} )
{
	my $groupname = Vhffs::Group::get_name_by_gid( $vhffs , $obj->get_owner_gid );
	my $dbname = $obj->get_dbname;

	my $dir = Vhffs::Functions::hash_groupname( $groupname , $vhffs );
	next unless -d $dir;

	my $file = $dir.'/'.$dbname.'.mysql.dump';
	my $cmd = $mysqlconf->{'mysqldump_path'}.' -c -R --hex-blob -u '.$mysqlconf->{'username'}.' -h '.$mysqlconf->{'host'}.' -p'.$mysqlconf->{'password'}.' '.$dbname.' > '.$file;

	system( $cmd );

	chown( $obj->get_owner_uid , $obj->get_owner_gid , $file ) if -f $file;
}

Vhffs::Robots::unlock( $vhffs , 'dumpmysql' );

exit 0;
