#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

require 5.004;
use strict;
use utf8;
use POSIX;
use locale;
use Locale::gettext;
use lib '%VHFFS_LIB_DIR%';
use Vhffs::Main;
use Vhffs::Robots;
use Vhffs::Group;
use Vhffs::Services::Repository;
use Quota;

my $vhffs = init Vhffs::Main;

Vhffs::Robots::lock( $vhffs , "setquotarepository" );

my $groups = Vhffs::Group::getall( $vhffs , Vhffs::Constants::ACTIVATED );
my $group;
my $quota;
my $blocks;
my $inodes;
my $repos;
my $repo;
my $users;
my $user;
my $dev = Quota::getqcarg($vhffs->get_config->get_datadir."/".Vhffs::Constants::REPOSITORYDIR);

foreach $group ( @{$groups} )
{
	if( defined $group )
	{
		$quota = 0;
		$blocks = 0;
		$inodes = 0;

		$repos = Vhffs::Services::Repository::getall_per_group( $vhffs, $group);
		if( scalar(@{$repos}) > 0 )
		{
			foreach $repo ( @{$repos} )
			{
				if( defined $repo )
				{
					$quota += $repo->get_quota;
					$blocks += $repo->get_quota * 1024;
					$inodes += $repo->get_quota * 1126400 / 100;
				}
			}

			unless( Quota::setqlim($dev, $group->get_gid, $blocks, $blocks, $inodes, $inodes, 0, 1) )
			{
				Vhffs::Robots::vhffs_log( sprintf( "Update quota for repositories of group %s to %s MB" , $group->get_groupname , $quota ) , $vhffs);
			}
			else
			{
				printf("Cannot update quota for repositories of group %s, reason: %s\n", $group->get_groupname, Quota::strerr);
			}
		}
		else
		{
			# give no space for groups without download repository
			if( Quota::setqlim($dev, $group->get_gid, 1, 1, 1, 1, 0, 1) )
			{
				printf("Cannot update quota for repositories of group %s, reason: %s\n", $group->get_groupname, Quota::strerr);
			}
		}
	}
}


# give no space for users
$users = Vhffs::User::getall( $vhffs , Vhffs::Constants::ACTIVATED );

foreach $user ( @{$users} )
{
	if( defined $user )
	{
		# give no space for all primary groups of users
		if( Quota::setqlim($dev, $user->get_gid, 1, 1, 1, 1, 0, 1) )
		{
			printf("Cannot update quota for repositories of primary group of user %s, reason %s\n", $user->get_username, Quota::strerr);
		}
	}
}


Vhffs::Robots::unlock( $vhffs , "setquotarepository" );

exit 0;
