#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::Robots;
use Vhffs::Robots::User;
use Vhffs::User;
use Vhffs::Constants;
use Vhffs::Main;


my $vhffs = init Vhffs::Main;

Vhffs::Robots::lock( $vhffs , "usergroup" );

my $lol = Vhffs::User::getall( $vhffs , Vhffs::Constants::TO_DELETE );
my $user;
my $groups;
my $group;
foreach $user ( @{$lol} )
{
	my $ok = 1;
	if( defined $user ) 
	{
		$groups =  $user->get_groups;

		if( defined $groups )
		{
			foreach $group ( @{$groups} )
			{
				Vhffs::Robots::vhffs_log( sprintf("Delete %s, remains group(s) : will delete %s " , $user->get_username , $group->get_groupname ) , $vhffs);
				if( $group->get_owner_uid == $user->get_uid )
				{
					$ok = 0;
					$group->set_status( Vhffs::Constants::TO_DELETE );
					$group->commit;
				}
			}
		}
		
		if( $ok == 1 )
		{
			Vhffs::Robots::vhffs_log( sprintf( "USER delete user %s" , $user->get_username ) , $vhffs);
        	if( Vhffs::Robots::User::delete( $vhffs, $user ) < 0 )
			{
				Vhffs::Robots::vhffs_log( sprintf("Cannot delete user files %s" , $user->get_username ) , $vhffs);
			}
			else
			{
				Vhffs::Robots::vhffs_log( sprintf("Delete user files %s" , $user->get_username ) , $vhffs);
			}

			if( $user->delete < 0 )
			{
				Vhffs::Robots::vhffs_log( sprintf("Cannot delete user object %s" , $user->get_username ) , $vhffs);
			}
			else
			{
				Vhffs::Robots::vhffs_log( sprintf("Delete user object %s" , $user->get_username ) , $vhffs);
			}
		}
		else
		{
			Vhffs::Robots::vhffs_log( sprintf("Cannot remove user %s, remains group(s)" , $user->get_username ) , $vhffs);
		}
	}
}

Vhffs::Robots::unlock( $vhffs , "usergroup" );
exit 0;
